==> jc-1.4.0.tar.gz: javax/swing/plaf/InputMapUIResource.h <==
// public class javax.swing.plaf.InputMapUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 790c4e1b642750d1 javax_swing_InputMap
// @dep_class 4ff4897a9b225d2d javax_swing_plaf_InputMapUIResource

// header file dependencies
// @dep_header javax_swing_InputMap

#include "javax/swing/InputMap.h"

#ifndef _JC_javax_swing_plaf_InputMapUIResource_H_
#define _JC_javax_swing_plaf_InputMapUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_InputMapUIResource$sub_refs	_jc_javax_swing_plaf_InputMapUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs	_jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$refs	_jc_javax_swing_plaf_InputMapUIResource$refs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$nonrefs	_jc_javax_swing_plaf_InputMapUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$object	_jc_javax_swing_plaf_InputMapUIResource$object;

typedef const struct _jc_javax_swing_plaf_InputMapUIResource$vmethods	_jc_javax_swing_plaf_InputMapUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_InputMapUIResource$vtable	_jc_javax_swing_plaf_InputMapUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_InputMapUIResource$vtype	_jc_javax_swing_plaf_InputMapUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_InputMapUIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_InputMapUIResource$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_InputMapUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_InputMapUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_plaf_InputMapUIResource$vmethods	javax_swing_plaf_InputMapUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_InputMapUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_InputMapUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_InputMapUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_InputMapUIResource$refs {
    _jc_javax_swing_plaf_InputMapUIResource$sub_refs	javax_swing_plaf_InputMapUIResource;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_InputMapUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs	javax_swing_plaf_InputMapUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_InputMapUIResource$object {
	_jc_javax_swing_plaf_InputMapUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_InputMapUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_InputMapUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_InputMapUIResource$vtype _jc_javax_swing_plaf_InputMapUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_InputMapUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_InputMapUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_InputMapUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/InputMapUIResource.h <==
// public class javax.swing.plaf.InputMapUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 790c4e1b642750d1 javax_swing_InputMap
// @dep_class 4ff4897a9b225d2d javax_swing_plaf_InputMapUIResource

// header file dependencies
// @dep_header javax_swing_InputMap

#include "javax/swing/InputMap.h"

#ifndef _JC_javax_swing_plaf_InputMapUIResource_H_
#define _JC_javax_swing_plaf_InputMapUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_InputMapUIResource$sub_refs	_jc_javax_swing_plaf_InputMapUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs	_jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$refs	_jc_javax_swing_plaf_InputMapUIResource$refs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$nonrefs	_jc_javax_swing_plaf_InputMapUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_InputMapUIResource$object	_jc_javax_swing_plaf_InputMapUIResource$object;

typedef const struct _jc_javax_swing_plaf_InputMapUIResource$vmethods	_jc_javax_swing_plaf_InputMapUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_InputMapUIResource$vtable	_jc_javax_swing_plaf_InputMapUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_InputMapUIResource$vtype	_jc_javax_swing_plaf_InputMapUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_InputMapUIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_InputMapUIResource$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_InputMapUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_InputMapUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_plaf_InputMapUIResource$vmethods	javax_swing_plaf_InputMapUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_InputMapUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_InputMapUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_InputMapUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_InputMapUIResource$refs {
    _jc_javax_swing_plaf_InputMapUIResource$sub_refs	javax_swing_plaf_InputMapUIResource;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_InputMapUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_plaf_InputMapUIResource$sub_nonrefs	javax_swing_plaf_InputMapUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_InputMapUIResource$object {
	_jc_javax_swing_plaf_InputMapUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_InputMapUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_InputMapUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_InputMapUIResource$vtype _jc_javax_swing_plaf_InputMapUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_InputMapUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_InputMapUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_InputMapUIResource_H_ */
